@@ -1,27 +1,26 @@
-from typing import Any, List, Type
 from abc import ABCMeta, abstractmethod
+from typing import Any, List, Type
 
 from graia.broadcast.entities.decorator import Decorator
-from ..entities.event import BaseEvent
+
+from ..entities.event import Dispatchable
 from ..typing import T_Dispatcher
 
 
 class Waiter(metaclass=ABCMeta):
-    listening_events: List[Type[BaseEvent]]
+    listening_events: List[Type[Dispatchable]]
     using_dispatchers: List[T_Dispatcher]
     using_decorators: List[Decorator]
     priority: int
-    enable_internal_access: bool
     block_propagation: bool
 
     @classmethod
     def create(
         cls,
-        listening_events: List[Type[BaseEvent]],
+        listening_events: List[Type[Dispatchable]],
         using_dispatchers: List[T_Dispatcher] = None,
         using_decorators: List[Decorator] = None,
         priority: int = 15,  # 默认情况下都是需要高于默认 16 的监听吧...
-        enable_internal_access: bool = False,
         block_propagation: bool = False,
     ) -> Type["Waiter"]:
         async def detected_event(self) -> Any:
@@ -35,7 +34,6 @@ class Waiter(metaclass=ABCMeta):
                 "using_dispatchers": using_dispatchers,
                 "using_decorators": using_decorators,
                 "priority": priority,
-                "enable_internal_access": enable_internal_access,
                 "block_propagation": block_propagation,
                 "detected_event": abstractmethod(detected_event),
             },
@@ -47,11 +45,10 @@ class Waiter(metaclass=ABCMeta):
     @classmethod
     def create_using_function(
         cls,
-        listening_events: List[Type[BaseEvent]],
+        listening_events: List[Type[Dispatchable]],
         using_dispatchers: List[T_Dispatcher] = None,
         using_decorators: List[Decorator] = None,
         priority: int = 15,  # 默认情况下都是需要高于默认 16 的监听吧...
-        enable_internal_access: bool = False,
         block_propagation: bool = False,
     ):
         def wrapper(func):
@@ -63,7 +60,6 @@ class Waiter(metaclass=ABCMeta):
                         using_dispatchers,
                         using_decorators,
                         priority,
-                        enable_internal_access,
                         block_propagation,
                     ),
                 ),
